==> haskell-binary-tagged-0.3-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-tagged
version:              0.3
visibility:           public
id:                   binary-tagged-0.3-6EK8OdG5oi9Ks6Qbhz8ZN1
key:                  binary-tagged-0.3-6EK8OdG5oi9Ks6Qbhz8ZN1
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Tagged binary serialisation.
description:
    Structurally tag binary serialisation stream.

    Say you have:

    Say you have a data type

    @
    data Record = Record
    \  { _recordFields  :: HM.HashMap Text (Integer, ByteString)
    \  , _recordEnabled :: Bool
    \  }
    \  deriving (Eq, Show, Generic)

    instance @Binary@ Record
    instance '\''Structured'\'' Record
    @

    then you can serialise and deserialise @Record@ values with a structure tag by simply

    @
    '\''structuredEncode'\'' record :: LBS.ByteString
    '\''structuredDecode'\'' lbs    :: IO Record
    @

    If structure of @Record@ changes in between, deserialisation will fail early.

    The overhead is next to non-observable.

    @
    benchmarking encode/Binary
    time                 352.8 μs   (349.5 μs .. 355.9 μs)

    benchmarking encode/Tagged
    time                 350.8 μs   (349.0 μs .. 353.1 μs)

    benchmarking decode/Binary
    time                 346.8 μs   (344.7 μs .. 349.9 μs)

    benchmarking decode/Tagged
    time                 353.8 μs   (352.0 μs .. 355.8 μs)
    @

category:             Data
abi:                  7ba6f472fdfe125522d3cb69674d473e
exposed:              True
exposed-modules:      Data.Binary.Tagged
import-dirs:          /usr/lib/ghc-8.10.3/site-local/binary-tagged-0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/binary-tagged-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/binary-tagged-0.3
hs-libraries:         HSbinary-tagged-0.3-6EK8OdG5oi9Ks6Qbhz8ZN1
depends:
    array-0.5.4.0 base-4.14.1.0
    base16-bytestring-1.0.1.0-2bKktddHaY9H9zJsf0Vy35 binary-0.8.8.0
    bytestring-0.10.12.0 containers-0.6.2.1
    structured-0.1-ELOsbJiZvpi51r2hmm3T3h
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe

haddock-interfaces:
    /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock

haddock-html:         /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.3-62-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-tagged
version:              0.3
visibility:           public
id:                   binary-tagged-0.3-6req17QjXIjHuk1wjwxh7o
key:                  binary-tagged-0.3-6req17QjXIjHuk1wjwxh7o
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Tagged binary serialisation.
description:
    Structurally tag binary serialisation stream.

    Say you have:

    Say you have a data type

    @
    data Record = Record
    \  { _recordFields  :: HM.HashMap Text (Integer, ByteString)
    \  , _recordEnabled :: Bool
    \  }
    \  deriving (Eq, Show, Generic)

    instance @Binary@ Record
    instance '\''Structured'\'' Record
    @

    then you can serialise and deserialise @Record@ values with a structure tag by simply

    @
    '\''structuredEncode'\'' record :: LBS.ByteString
    '\''structuredDecode'\'' lbs    :: IO Record
    @

    If structure of @Record@ changes in between, deserialisation will fail early.

    The overhead is next to non-observable.

    @
    benchmarking encode/Binary
    time                 352.8 μs   (349.5 μs .. 355.9 μs)

    benchmarking encode/Tagged
    time                 350.8 μs   (349.0 μs .. 353.1 μs)

    benchmarking decode/Binary
    time                 346.8 μs   (344.7 μs .. 349.9 μs)

    benchmarking decode/Tagged
    time                 353.8 μs   (352.0 μs .. 355.8 μs)
    @

category:             Data
abi:                  85c15809e761a2e74814e478671b7df2
exposed:              True
exposed-modules:      Data.Binary.Tagged
import-dirs:          /usr/lib/ghc-8.10.3/site-local/binary-tagged-0.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/binary-tagged-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/binary-tagged-0.3
hs-libraries:         HSbinary-tagged-0.3-6req17QjXIjHuk1wjwxh7o
depends:
    array-0.5.4.0 base-4.14.1.0
    base16-bytestring-1.0.1.0-LpdmR3cRLho38k1NEAzqqP binary-0.8.8.0
    bytestring-0.10.12.0 containers-0.6.2.1
    structured-0.1-LqBVC0CLr6oL0PfKns1gyE
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C

haddock-interfaces:
    /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock

haddock-html:         /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
